from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x09\x00\x61\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x99\x08\x00\x00\x00\x00\x00\x18\x8d\xa5\x1a\x3e\x88\xa9\x0d\x4e\xaa\x4b\x5c\x1a\x73\x62\x27\x2e\x00\x00\x00\x00\x00\x00\x00\x00\xf7\x86\x89\x4f\x6e\x6d\x92\x8f\x8e\x9c\xf0\x76\xe4\x64\x8a\x4f\xcb\xaf\x28\xe6\x47\xab\x33\xa8\xc4\x5b\xee\xc7\xea\x1d\xeb\x76\x60\xd7\x2b\x7a\x80\xa5\xdd\x8b\x0e\x8c\xf3\xc2\xe2\xbd\xa6\x5d\xc5\x02\x3b\x61\x31\x91\xeb\xb1\x19\xa7\x23\xef\x3b\xa0\xde\x50\x5c\xd2\x6c\x19\x10\x64\xfe\x37\x7f\xa8\x7d\x80\x13\x1b\x99\xc0\x38\x3e\x5b\x07\x50\x69\x75\x41\x78\xe9\x93\x94\xe9\x84\x04\x5f\xce\x27\x18\xb7\xe7\xca\xc8\x28\x15\xcc\x05\x21\x29\x93\x4a\x59\x4f\x8f\xaa\x6c\x2a\xd3\x62\x8b\xa5\x66\xe3\x95\x6e\xf6\x2b\x3d\xef\xce\x09\xb1\x82\x85\xed\xbe\x55\x02\xc9\xce\x87\xaa\xe1\x40\xa0\xa9\x27\xd1\x6a\x52\xe5\x7c\x8e\xa1\xdb\xac\x1e\xa0\x85\x12\x48\x61\x04\x37\x33\x3b\x52\x60\x53\x52\x8e\xb5\x73\x7a\xe2\x6c\x72\xd9\xd4\x7a\xc3\x2f\xd7\xf9\xcc\xf6\x96\x49\xb9\xd7\x66\x76\x7e\x3d\x77\x46\xa9\xc4\xc0\x23\x38\xbd\xef\x4f\x13\x5f\xad\xd8\x8c\x17\x82\xcd\x24\x8c\x24\xd6\x62\x83\x53\xbe\xd9\x8f\xce\x4d\x51\xf0\x76\x68\xb5\x47\x30\xf5\xe6\x5f\xf4\x91\x35\x52\xcf\xa1\x84\x8a\x79\xa9\x06\x1a\x41\x7c\xcd\xc2\x89\x38\x51\x31\xca\x46\xbd\xfc\x42\xea\xec\xa9\xa8\xf4\xc5\x24\x73\xb3\x6d\x10\x4e\xa5\xa7\x6c\x45\x2f\xb8\x49\xcd\x86\xc5\xf3\xa6\xab\xf3\x71\xbc\x8a\xb2\xe0\x6d\xa7\xad\xaf\x63\xee\xa0\xa2\xe0\x2c\x35\x41\xc1\x86\x4f\x59\x5d\xd3\x00\x30\x13\x24\x9a\x42\x50\x9d\xe4\x3b\xfb\x46\x81\x28\x9a\xbd\x4d\x78\x6a\xd1\x41\xb3\xb7\xbe\xa6\x50\x1f\x67\x4d\xe0\x2e\x5a\x2f\x87\x09\x26\xe3\xf0\x71\xbb\xac\xcc\x2d\x8a\x25\x7d\x24\x64\xe5\x61\xb1\x1a\xbd\x27\x97\x5d\x48\x2c\xaf\x86\x74\x0c\xea\xee\x57\x70\x97\x74\x3a\x57\x7e\x5b\xd8\x78\xd1\x9e\x81\xbc\x7c\x3f\xf7\x1c\xd7\x71\x88\x51\xe4\xe8\xae\x2b\xfe\x8f\x99\x68\x82\x33\x36\x13\xd9\x00\xa3\xca\xbf\x8b\x5f\xf1\x7a\x37\xca\xb6\xdb\x21\xbf\x2a\x00\xbc\x98\x76\xc8\x21\x2a\x48\x04\xd4\x2f\x25\x95\x45\xde\x6c\x3b\xd7\x9b\x00\x87\x38\xf0\xdb\x5c\x6b\x6d\x60\x5c\xce\x70\x2d\xa8\x58\x3b\x8e\x18\x29\xa1\xa9\x3e\x2a\x23\xa5\x7c\xd4\xcb\xb7\x51\x74\xc8\x57\x09\x64\xb2\xc1\x34\xd1\x5c\x23\xb4\x25\x50\xd5\x4f\x67\xa1\x08\x8b\x82\x20\xc9\x54\xa9\x54\xa7\x86\xea\x1c\xbf\x04\x95\xae\x75\xad\x6e\x90\xb7\x2b\x58\xde\x7c\x4d\x85\x6c\x6c\x1c\x1d\x19\x48\xb3\xc7\x38\x75\x89\x6c\x61\xb0\x9e\xed\x4d\x69\xc1\x87\x2b\x51\xff\x08\xc9\xb9\x83\x8a\x84\x68\x1b\x19\x0b\x18\xa4\x51\x7e\xf8\xa4\xcf\x2e\x7b\x88\x72\xf1\xab\x9d\x8c\x97\x54\xb0\xd8\x4d\x82\x49\xb5\xc2\x3a\xce\x78\x3d\x54\x7b\x48\x0f\x6b\x23\x42\xde\x7a\x8c\x8c\x42\xa0\x76\x7c\xf2\x4d\xfc\x89\xbe\xc5\x83\x0a\xf0\x7f\xd5\xca\xe4\xd2\x52\x90\x2f\xce\x75\x04\x5f\x30\xbe\x9b\x5b\x5b\xb8\x26\xaf\x5d\x0c\xac\x8b\xa2\x22\xe7\x39\xda\x08\xc7\xce\x15\xf6\x9a\x12\x20\xe4\xd1\x9d\x7a\x58\x9e\x8c\xfb\xa7\x49\xa7\x2c\x25\xd4\x5a\xb3\xe4\xbd\x82\xe0\x7a\x08\x31\x27\x99\x23\xd2\xb2\x3c\x28\xeb\xee\x7d\xa3\x07\xe5\x1e\x04\x74\x4a\x3a\xc7\x10\xf5\x9d\x25\xa6\x32\x74\xe7\x59\x2a\xc9\xd4\xf2\x3e\xea\x04\xc4\x7d\x93\x1a\x1c\x35\x89\x43\x78\xdf\xdb\x2d\xff\x02\xb8\x65\x98\x72\x49\x3f\x42\x30\x0c\x56\xa5\x14\x9d\xe8\x2a\x15\x2b\x45\xda\xd6\x8d\xa3\xe3\x46\xd0\x44\x11\xe6\x74\x99\x95\x80\xbb\x52\xf6\xdf\x6d\x95\xd1\xc7\x36\x8e\x45\xe7\xb5\x5f\x42\xa0\x28\x28\x22\xcf\x26\x1a\x40\x0b\x65\xef\x19\xab\xcb\x00\xa0\xe0\xd8\x26\x8b\x0c\x43\xe3\xd8\x5b\x02\xd8\xd8\xc6\x50\x8c\x75\xe5\x86\x71\x6e\xaa\x18\xf9\x5d\xa0\xe5\xe3\x14\x59\x4d\x3b\x24\xf1\x51\xe8\x49\xc5\xe1\x76\xc1\x12\x12\xfd\x80\x8e\xa3\x26\xe4\xbe\x65\x2f\x59\x01\xb1\x81\xa2\xa2\x0a\xeb\x25\x6a\x5e\x41\xbf\x3b\x37\x76\x1a\xad\xc1\x08\xe3\x20\xfc\x8a\xfd\x62\x51\x84\xb5\xae\x19\x71\xb3\x7d\xe9\x44\x19\x2a\x13\xb4\xd2\x1f\xb0\xef\xb4\x87\xd7\x58\xd2\xc1\x48\x2c\x13\x58\x76\x25\xd1\x2f\x02\xf7\xb0\x2f\x87\x9c\xbc\x78\x43\xa6\xf7\xa3\xe5\x5b\x8e\x3e\x6c\x6a\xb9\xe5\xcd\xaf\xe4\x7b\xa1\xa8\x06\xd9\xc8\x60\xaa\x21\x3e\x7c\x97\x41\xfb\xa6\x2f\xc1\x5b\x47\x39\x14\x13\xb5\x1f\x2f\x48\x34\x6b\xcd\x40\xca\xf9\xdb\x81\x28\xbe\xd0\xdc\x84\x4c\x2a\x9e\x11\xed\xd4\xdf\xb8\x93\x56\x1e\x91\x8a\xf5\x38\x88\x26\x6f\x56\x6b\x3f\x61\x85\x37\x5c\xc5\x28\xa7\x79\x9a\xe9\x9b\xed\xf7\x6d\x3e\x03\xc4\x16\x4e\xfc\x0d\xd8\xf1\x03\x98\x9b\x7e\xa8\x0e\x89\xc5\xe9\xa0\xea\x4d\xb6\x63\x7d\xe0\x93\x23\xd3\x0d\x33\x74\x69\x0a\xaf\xdb\x9e\xcd\x9c\x84\x78\xc8\xd2\x9a\xf5\x17\x4e\xd3\x81\x8a\x2a\xcd\x0c\x9c\x67\x31\x3e\x78\xc6\xd5\x5e\x0d\x79\xa4\xac\xa4\x82\x9b\xc4\x41\xb4\xf2\xab\x11\xa0\x62\x5e\x76\xbd\xa9\x00\x3c\x01\x4d\x79\xb5\x8a\xdb\x7e\x41\xd2\x46\x4e\xc4\xfa\xe5\x3e\x61\xc5\xeb\xab\xe6\x0a\x89\xba\xb9\xb0\x4f\xb6\x77\xfb\x0c\x7d\x76\x5c\xfb\x22\xef\x14\xe4\xcb\x8f\x28\xd1\x26\x5a\xa2\xe6\xdc\x3a\xff\x07\xd1\xb4\x39\xb5\xca\x5f\x2d\x64\x8d\xd6\x53\xa8\x64\x91\xf3\x08\x4f\xa4\x45\x53\x57\xff\xfd\x71\xad\x09\x04\x5a\x37\x9d\x45\x7c\x9d\x32\xab\x7c\xbf\x2a\xd1\x03\xe2\xcd\xb9\xe8\x09\x50\xb1\x85\xbe\xdc\xd9\x9b\x67\xb3\x16\x94\x97\x8a\x74\x26\x89\xb5\xbf\x96\xa7\xa3\x54\x07\x16\x48\xa1\xb8\xec\x2a\x94\xfa\x1a\xa2\x13\x91\xcf\x5c\xe4\x9a\xeb\x90\xcd\x03\x3c\x85\x42\xc7\x31\x40\x90\x14\xd2\xac\x65\x4b\x09\xef\xec\x1d\xae\x9c\x94\x20\x1d\x32\x45\xbc\xc8\xc6\x26\x32\xd0\x47\xd4\xea\x79\x3f\x62\x84\x79\xe0\x58\x2c\x84\x22\xba\x3f\x5c\x4c\x22\xd6\xd3\x65\x7b\xd1\x26\xee\xe6\x9c\x12\xf7\xe3\x81\x72\xc1\x33\x55\x3c\x04\x11\xc8\xad\x93\x61\x74\xe7\xaa\x82\x9a\x6c\xde\xa0\xa1\x17\xca\x18\x23\xa5\x5b\xa4\x67\x56\x31\x62\xd3\x97\xf0\xbf\x83\x4a\x0b\x1a\x5e\xf8\x79\x60\xb0\x90\x5c\x5f\xa6\x5b\x25\x98\xf5\x9b\xc5\xf5\xeb\x49\x57\x50\x63\xb5\xd4\x8b\x8c\x4c\x16\x4d\xa1\x83\xf9\x4e\x9b\x9a\x9f\xa6\x8d\x02\x86\x71\x40\xe3\x5d\x93\xdf\x8f\xbe\xa1\xe8\xa4\xf1\xa5\xfb\x18\x6b\xe8\x36\xfc\xba\xff\x13\x68\xe6\xf1\x7b\xa4\x64\xb2\x27\x37\x17\xe0\x72\xba\xe3\x32\xd1\x8e\xab\x8f\x41\xca\xcc\xba\x7a\xf0\x01\xbe\xbc\x5a\xbd\x84\x9b\x57\x6a\xab\xee\xf9\x91\x59\xb7\xaa\xac\x8c\x1b\xf6\x1a\xc3\xe2\xc6\xd2\x16\x95\x4f\xfd\xc7\xc6\xa5\x5e\x28\x69\x39\xbe\x77\x0a\xe8\x0e\x4b\x81\x31\x17\x50\x9e\x1d\x87\x29\x82\xc2\x3f\x32\x56\x57\x76\x46\x26\x3a\x49\xfe\xe1\xec\x52\xfb\x67\xe1\x23\x49\xe2\xfc\x30\xab\xf9\xa4\x9b\xe3\xc9\xac\xbb\x10\xbb\x3f\xee\x93\x18\xc1\x8e\xe7\x4a\x70\x4a\x83\xba\x8b\xa3\x8a\x4d\x4e\x45\xdb\xee\x14\xde\xf0\xfb\xc0\x93\xca\x74\x9c\xaf\xc7\x5b\x88\x94\x5a\xb0\xb1\xb5\x93\xf0\xe6\xa5\x17\xcc\xe1\x03\xb6\xf7\x12\x8d\x85\x0b\x72\xf1\x6c\x41\xa0\x37\xcf\x6d\xe7\xbb\xa0\x60\x6c\x7a\x3e\xbf\x95\xa2\xed\x33\x67\x20\x56\x04\xfe\x8b\x5b\x91\x4b\x57\x94\x0e\x1a\xbe\xe7\x12\x60\xdc\x9d\x41\x8d\x4c\xeb\x7e\x98\xe1\x6c\x7b\x99\x96\x67\xa0\xff\x3d\xf7\x8a\x4c\x69\xd9\x47\x30\x4b\x1e\x86\xbe\x38\x95\xe5\x5e\xa0\xe6\xb6\x51\x01\xf0\xe9\xa8\x98\x4c\xcd\x99\x8c\x5f\x94\x9e\x9a\x39\x8a\xc3\xa4\xf7\xba\x60\x97\x06\x7b\x76\xa6\xb3\x56\x9b\x48\xfb\xe0\xa9\x32\x0f\x41\x6a\x09\xa0\x0f\xd8\x02\x9e\x82\xc3\x98\xab\xbf\xb4\x51\x71\x72\xf7\x7a\x39\x9a\x5a\xea\x57\x1c\x4f\xbd\x18\xef\x77\x27\xd4\x49\xac\x87\x9a\xa0\x20\x49\x6e\x63\x96\x71\x13\x56\xf3\xa5\x1e\xcf\x15\x79\xba\x66\xf2\x39\x10\xfb\x47\xa2\xde\x0f\x5e\x1e\x54\x17\x85\x7e\x8c\x69\xa0\x41\xe1\x78\x15\x43\x8e\x8d\x81\xa2\xa1\x75\xb9\x80\x6b\x25\x9f\xb9\xc3\xb4\x1b\xee\xeb\xad\x07\x16\x08\xef\x69\xea\xe3\xb6\xc4\x00\x5f\xfc\xa1\x4a\x54\x13\x06\xeb\xc4\xd0\xc8\xb0\xaa\x7a\x2b\xae\x93\x6d\x12\x36\x2b\x67\xd1\xea\x5c\x01\x00\x14\xa8\x96\x58\x85\xfa\xb9\x38\x27\xfb\xcc\x49\x67\x36\xa5\xf7\xb5\x25\xe3\x9b\xc5\xc5\xc6\x05\x56\xde\x08\xf5\xc6\xc2\xd9\x6f\x34\x43\xf5\x11\x64\x34\x35\x45\xeb\x76\xc3\x22\x41\x30\x67\xcb\x1b\xc8\x51\x2c\x09\xd1\x45\x2f\x0c\xc5\x83\xd6\xbe\xfe\x3d\xc5\x0e\x79\xfb\x21\x25\xdb\x62\xeb\xcf\x6c\xa4\x9d\x12\xc2\xf0\xd5\xb7\x3b\xde\xaa\xc2\x52\x12\xe2\x94\x8e\x6a\x59\x21\x0b\xd3\xd4\x72\xe6\x82\xcc\xf8\xf1\x10\xa4\xbd\xb7\xda\xce\x90\x6f\x08\xb8\xa4\xc5\x82\x82\xb4\x9b\xdb\x10\x3a\x3f\x29\xb1\x34\x91\xdc\x77\xe7\x25\x1f\x3e\x20\x75\x9a\x80\xfe\x6a\xfa\x80\x0b\x01\x42\x21\x8b\x15\x1a\x86\x01\x3e\xb4\xa0\xd6\xd0\x59\x95\xc5\x0c\x99\x78\x74\x7a\xe9\x7c\x3d\x8b\xe9\xf4\x0d\x60\x8e\xa8\x4f\x08\xee\x1c\x1c\x10\x27\x26\x2b\xe1\x2f\x2f\xa6\x41\x36\xf6\x5c\x21\x49\x8d\xb3\xb5\x79\x45\x5c\x90\x5a\x3c\x00\x39\xee\x90\x74\x91\x6b\x94\x4d\xcd\x8b\x97\xa5\x46\x97\xc5\xc3\xa4\x8a\x23\x8a\xda\x15\xd7\xf4\x0b\xa5\x35\x81\x4a\xdc\x3b\xd8\xd6\x0b\x94\x22\x94\x05\x8a\xdd\xb9\x8f\x76\xd0\xb8\xa1\x58\x9a\xfe\x95\x96\x2b\x9f\x0c\xde\x5e\x36\xdc\x6e\x03\x71\x24\x71\x9c\x0d\x04\x6a\x91\x8f\x0d\x8c\xd6\x5b\x1f\xda\x40\x47\x7d\x9f\x95\x60\xe6\x4f\x9e\x5d\x11\xaa\xc7\xdd\x89\x01\xd3\x5f\xf9\x8c\x7f\xeb\x89\x7d\x0b\x9f\xa7\xeb\x22\xac\xf5\xff\x1a\x1d\xf2\x81\x8a\x95\x92\xec\xa5\x25\x94\x19\x56\xe7\xb7\xa5\xeb\x72\x0d\xf3\xb8\xba\x4b\x90\x19\x26\x04\xa0\xf5\xfc\xd1\x07\x84\x45\x4c\xee\x41\x3f\xdb\xcc\x27\xc1\xe8\x30\x7a\x28\x11\xd8\x0f\x7c\x82\xe2\xf4\x7e\x6b\x98\x1c\x08\xf3\x3f\x3b\x38\xd1\x3a\x4e\x68\x3f\xd8\x91\x41\xa7\x13\xff\x64\xd3\x71\x68\x75\x98\x78\xdf\x52\x02\x85\x3c\xd7\xdb\x85\x6e\x3d\x35\x02\x9b\x4e\x13\x19\xa7\xea\x65\xde\xfb\xd3\xd4\x93\x19\x23\x9d\x76\x8b\x8b\x51\xdb\xc1\x61\x25\xa7\x53\x60\x4a\x17\x62\xbc\xc9\xce\x2e\x31\xbf\x21\x5c\xd8\xab\xa0\x00\xa5\x64\xe8\xaa\x1c', 2)

# cleanup
del pyarmor_runtime

